==> bitcoin-sv-0.1.1.tar.gz: bitcoin-sv-0.1.1/test/functional/bsv-128Mb-blocks.py <==
#!/usr/bin/env python3
# Copyright (c) 2015-2016 The Bitcoin Core developers
# Copyright (c) 2017 The Bitcoin developers
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
"""
This test checks that by using the newly promoted -excessiveblocksize
flag we can actually process very big blocks.
"""

from test_framework.test_framework import ComparisonTestFramework
from test_framework.util import assert_equal, assert_raises_rpc_error
from test_framework.comptool import TestManager, TestInstance, RejectResult
from test_framework.blocktools import *
import time
from test_framework.script import *
from test_framework.cdefs import (ONE_MEGABYTE)

class BSV128MBlocks(ComparisonTestFramework):

    def set_test_params(self):
        self.num_nodes = 1
        self.setup_clean_chain = True
        self.excessive_block_size = 128 * ONE_MEGABYTE
        self.extra_args = [['-whitelist=127.0.0.1',
                            "-excessiveblocksize=%d" % self.excessive_block_size]]

    def add_options(self, parser):
        super().add_options(parser)

    def run_test(self):
        self.nodes[0].setexcessiveblock(self.excessive_block_size)
        self.test.run()

    def get_tests(self):
        node = self.nodes[0]
        self.chain.set_genesis_hash( int(node.getbestblockhash(), 16) )

        # shorthand for functions
        block = self.chain.next_block

        # Create a new block
        block(0)
        self.chain.save_spendable_output()
        yield self.accepted()

        # Now we need that block to mature so we can spend the coinbase.
        test = TestInstance(sync_every_block=False)
        for i in range(99):
            block(5000 + i)
            test.blocks_and_transactions.append([self.chain.tip, True])
            self.chain.save_spendable_output()
        yield test

        # collect spendable outputs now to avoid cluttering the code later on
        out = []
        for i in range(100):
            out.append(self.chain.get_spendable_output())

        # block of maximal size
        block(1, spend=out[0], block_size=self.excessive_block_size)
        yield self.accepted()

        # Oversized blocks will cause us to be disconnected
        assert(not self.test.test_nodes[0].closed)
        block(2, spend=out[1], block_size=self.excessive_block_size + 1)
        self.test.connections[0].send_message(msg_block((self.chain.tip)))
        self.test.wait_for_disconnections()
        assert(self.test.test_nodes[0].closed)

        # Rewind bad block and remake connection to node
        self.chain.set_tip(1)
        self.restart_network()
        self.test.wait_for_verack()

        # Check we can still mine a good size block
        block(3, spend=out[1], block_size=self.excessive_block_size)
        yield self.accepted()

if __name__ == '__main__':
    BSV128MBlocks().main()

==> bitcoin-sv-1.0.3.tar.gz: bitcoin-sv-1.0.3/test/functional/bsv-128Mb-blocks.py <==
#!/usr/bin/env python3
# Copyright (c) 2015-2016 The Bitcoin Core developers
# Copyright (c) 2017 The Bitcoin developers
# Copyright (c) 2019 Bitcoin Association
# Distributed under the Open BSV software license, see the accompanying file LICENSE.
"""
This test checks that by using the newly promoted -excessiveblocksize
flag we can actually process very big blocks.
"""

from test_framework.test_framework import ComparisonTestFramework
from test_framework.util import assert_equal, assert_raises_rpc_error
from test_framework.comptool import TestManager, TestInstance, RejectResult
from test_framework.blocktools import *
import time
from test_framework.script import *
from test_framework.cdefs import (ONE_MEGABYTE)

class BSV128MBlocks(ComparisonTestFramework):

    def set_test_params(self):
        self.num_nodes = 1
        self.setup_clean_chain = True

    def add_options(self, parser):
        super().add_options(parser)
        parser.add_option("--excessiveblocksize", dest="excessive_block_size", default=128*ONE_MEGABYTE, type='int')

    def run_test(self):
        self.extra_args = [['-whitelist=127.0.0.1',
                    "-excessiveblocksize=%d" % self.options.excessive_block_size]]
        self.nodes[0].setexcessiveblock(self.options.excessive_block_size)
        self.test.run()

    def get_tests(self):
        self.log.info("Testing with -excessiveblocksize set to {} MB ({} bytes)"
            .format(
                (self.options.excessive_block_size/ONE_MEGABYTE),
                self.options.excessive_block_size))

        node = self.nodes[0]
        self.chain.set_genesis_hash( int(node.getbestblockhash(), 16) )

        # shorthand for functions
        block = self.chain.next_block

        # Create a new block
        block(0)
        self.chain.save_spendable_output()
        yield self.accepted()

        # Now we need that block to mature so we can spend the coinbase.
        test = TestInstance(sync_every_block=False)
        for i in range(99):
            block(5000 + i)
            test.blocks_and_transactions.append([self.chain.tip, True])
            self.chain.save_spendable_output()
        yield test

        # collect spendable outputs now to avoid cluttering the code later on
        out = []
        for i in range(100):
            out.append(self.chain.get_spendable_output())

        # block of maximal size
        block(1, spend=out[0], block_size=self.options.excessive_block_size)
        yield self.accepted()

        # Oversized blocks will cause us to be disconnected
        assert(not self.test.test_nodes[0].closed)
        block(2, spend=out[1], block_size=self.options.excessive_block_size + 1)
        self.test.connections[0].send_message(msg_block((self.chain.tip)))
        self.test.wait_for_disconnections()
        assert(self.test.test_nodes[0].closed)

        # Rewind bad block and remake connection to node
        self.chain.set_tip(1)
        self.restart_network()
        self.test.wait_for_verack()

        # Check we can still mine a good size block
        block(3, spend=out[1], block_size=self.options.excessive_block_size)
        yield self.accepted()

if __name__ == '__main__':
    BSV128MBlocks().main()
